==> kmyfirewall_0.9.6.2.orig.tar.gz: kmyfirewall-0.9.6.2/kmyfirewall/kmfxmlparser.h <==
/***************************************************************************
                       kmfxmlparser.h  -  description
                          -------------------
 begin                : Wed Aug 21 2002
 copyright            : (C) 2002 by animal
 email                : animal@shit.orphi.iki
***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#ifndef KMFXMLPARSER_H
#define KMFXMLPARSER_H


/**XML Parser for the kmyfirewall xml rulset
  *@author animal
  */ 
// qt includes
#include <qdom.h>

class KMFDoc;
class KMFError;
class KMFErrorHandler;
class KURL;
class KMFXMLParser {
public:
	KMFXMLParser();
	~KMFXMLParser();

	KMFDoc* parseKMFRS( const QString& filename );
	KMFError* writeKMFRS( KMFDoc* doc, const QString& filename );
	const QString& writeKMFRS( KMFDoc* kmfdoc );
private:
	QDomDocument domTree;
	void parseDocumenmtAbstract( const QDomElement &abstarct );
	KMFError* parseIPTRule( const QDomElement &rule );
	KMFError* parseIPTChain( const QDomElement &rule );
	KMFDoc *kmfdoc;
	KMFError *m_err;
	KMFErrorHandler *m_err_handler;
};

#endif

==> kmyfirewall_1.0.orig.tar.gz: kmyfirewall-1.0/kmyfirewall/kmfxmlparser.h <==
/***************************************************************************
 begin                : Wed Aug 21 2002
 copyright            : (C) 2002 by Christian Hubinger
 email                : chubinger@gmail.com.orphi.iki
***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#ifndef KMFXMLPARSER_H
#define KMFXMLPARSER_H


/**XML Parser for the kmyfirewall xml rulset
  *@author Christian Hubinger
  */ 
// qt includes
#include <qdom.h>

class KMFIPTDoc;
class KMFError;
class KMFErrorHandler;
class KURL;

class KMFXMLParser {
public:
	KMFXMLParser();
	~KMFXMLParser();

	KMFIPTDoc* parseKMFRS( const QString& filename );
	KMFError* writeKMFRS( KMFIPTDoc* doc, const QString& filename );
	const QString& writeKMFRS( KMFIPTDoc* kmfdoc );
private:
	QDomDocument domTree;
	void parseDocumenmtAbstract( const QDomElement &abstarct );
	KMFError* parseIPTRule( const QDomElement &rule );
	KMFError* parseIPTChain( const QDomElement &rule );
	KMFIPTDoc *kmfdoc;
	KMFError *m_err;
	KMFErrorHandler *m_err_handler;

};

#endif
